{
    "command": "/usr/sbin/haproxy-systemd-wrapper -f /etc/haproxy/haproxy.cfg -p /run/haproxy.pid",
    "config_files": [
        {
            "source": "{{ container_config_directory }}/haproxy.cfg",
            "dest": "/etc/haproxy/haproxy.cfg",
            "owner": "root",
            "perm": "0644"
        },
        {
            "source": "{{ container_config_directory }}/haproxy.pem",
            "dest": "/etc/haproxy/haproxy.pem",
            "owner": "root",
            "perm": "0600",
            "optional": {{ (not kolla_enable_tls_external | bool) | string | lower }}
        }
    ]
}
