{
    "command": "/opt/kibana/bin/kibana",
    "config_files": [
        {
            "source": "{{ container_config_directory }}/kibana.yml",
            "dest": "/opt/kibana/config/kibana.yml",
            "owner": "kibana",
            "perm": "0640"
        }
    ]
}
