{
    "command": "sleep infinity",
    "config_files":[
        {
            "source": "{{ container_config_directory }}/rally.conf",
            "dest": "/etc/rally/rally.conf",
            "owner": "rally",
            "perm": "0600"
        }
    ],
    "permissions": [
        {
            "path": "/var/log/kolla/rally",
            "owner": "rally:rally",
            "recurse": true
        }
    ]
}
