{
    "command": "/usr/sbin/rabbitmq-server",
    "config_files": [
        {
            "source": "{{ container_config_directory }}/rabbitmq-env.conf",
            "dest": "/etc/rabbitmq/rabbitmq-env.conf",
            "owner": "rabbitmq",
            "perm": "0600"
        },
        {
            "source": "{{ container_config_directory }}/rabbitmq.config",
            "dest": "/etc/rabbitmq/rabbitmq.config",
            "owner": "rabbitmq",
            "perm": "0600"
        },
        {
            "source": "{{ container_config_directory }}/rabbitmq-clusterer.config",
            "dest": "/etc/rabbitmq/rabbitmq-clusterer.config",
            "owner": "rabbitmq",
            "perm": "0600"
        },
        {
            "source": "{{ container_config_directory }}/definitions.json",
            "dest": "/etc/rabbitmq/definitions.json",
            "owner": "rabbitmq",
            "perm": "0600"
        }
    ],
    "permissions": [
        {
            "path": "/var/lib/rabbitmq",
            "owner": "rabbitmq:rabbitmq",
            "recurse": true
        },
        {
            "path": "/var/log/kolla/rabbitmq",
            "owner": "rabbitmq:rabbitmq",
            "recurse": true
        }
    ]
}
