{
    "command": "uwsgi --master --emperor /etc/barbican/vassals --logto /var/log/kolla/barbican/barbican-api.log",
    "config_files": [
        {
            "source": "{{ container_config_directory }}/barbican.conf",
            "dest": "/etc/barbican/barbican.conf",
            "owner": "barbican",
            "perm": "0600"
        },
        {
            "source": "{{ container_config_directory }}/vassals/barbican-api.ini",
            "dest": "/etc/barbican/vassals/barbican-api.ini",
            "owner": "barbican",
            "perm": "0600"
        },
        {
            "source": "{{ container_config_directory }}/barbican-api-paste.ini",
            "dest": "/etc/barbican/barbican-api-paste.ini",
            "owner": "barbican",
            "perm": "0600"
        }
    ]
}
