{
    "command": "/usr/sbin/keepalived -nld -p /run/keepalived.pid",
    "config_files": [
        {
            "source": "{{ container_config_directory }}/keepalived.conf",
            "dest": "/etc/keepalived/keepalived.conf",
            "owner": "root",
            "perm": "0644"
        }
    ]
}
