[DEFAULT]
bind_ip = {{ hostvars[inventory_hostname]['ansible_' + api_interface]['ipv4']['address'] }}
bind_port = {{ swift_object_server_port }}
devices = {{ swift_devices_mount_point }}
mount_check = false

log_address = /var/lib/kolla/heka/log
log_name = {{ service_name }}
log_facility = LOG_LOCAL0
log_level = INFO

[pipeline:main]
{% if service_name == 'swift-object-expirer' %}
pipeline = proxy-server
{% else %}
pipeline = object-server
{% endif %}

[app:object-server]
use = egg:swift#object

{% if service_name == 'swift-object-auditor' %}
[object-auditor]
{% endif %}

{% if service_name == 'swift-object-replicator' %}
[object-replicator]
sync_module = {replication_ip}:{meta}:object
{% endif %}

{% if service_name == 'swift-object-updater' %}
[object-updater]
{% endif %}

{% if service_name == 'swift-object-expirer' %}
[object-expirer]

[app:proxy-server]
use = egg:swift#proxy
{% endif %}
