defaults {
   user_friendly_names no
   polling_interval  30
}

blacklist {
    devnode "^(ram|raw|loop|fd|md|dm-|sr|scd|st)[0-9]*"
    devnode "^sd[a]"
    devnode "^hd[a-z]"
    devnode "^cciss!c[0-9]d[0-9]*"
}
