[DEFAULT]
debug = {{ glance_logging_debug }}

# NOTE(elemoine) log_dir alone does not work for Glance
log_file = /var/log/kolla/glance/api.log
use_forwarded_for = true

bind_host = {{ api_interface_address }}
bind_port = {{ glance_api_port }}
workers = {{ openstack_service_workers }}

{% if orchestration_engine == 'KUBERNETES' %}
registry_host = {{ glance_registry_host }}
{% else %}
registry_host = {{ kolla_internal_fqdn }}
{% endif %}

{% if enable_ceph | bool %}
show_image_direct_url= True
show_multiple_locations = True
{% endif %}

cinder_catalog_info = volume:cinder:internalURL

transport_url = rabbit://{% for host in groups['rabbitmq'] %}{{ rabbitmq_user }}:{{ rabbitmq_password }}@{% if orchestration_engine == 'KUBERNETES' %}rabbitmq{% else %}{{ hostvars[host]['ansible_' + hostvars[host]['api_interface']]['ipv4']['address'] }}{% endif %}:{{ rabbitmq_port }}{% if not loop.last %},{% endif %}{% endfor %}

[database]
connection = mysql+pymysql://{{ glance_database_user }}:{{ glance_database_password }}@{{ glance_database_address }}/{{ glance_database_name }}
max_retries = -1

[keystone_authtoken]
{% if orchestration_engine == 'KUBERNETES' %}
auth_uri = {{ keystone_internal_url }}
auth_url = {{ keystone_admin_url }}
{% else %}
auth_uri = {{ internal_protocol }}://{{ kolla_internal_fqdn }}:{{ keystone_public_port }}
auth_url = {{ admin_protocol }}://{{ kolla_internal_fqdn }}:{{ keystone_admin_port }}
{% endif %}
auth_type = password
project_domain_id = default
user_domain_id = default
project_name = service
username = {{ glance_keystone_user }}
password = {{ glance_keystone_password }}

{# For Kolla-Ansible, generate the memcache servers based on the list of
memcached servers in the inventory and memcached_servers should be un-set.
For Kolla-Kubernetes,  it is necessary to define the memcached_servers
variable in globals.yml to set it to the Kubernetes service for memcached. #}
memcache_security_strategy = ENCRYPT
memcache_secret_key = {{ memcache_secret_key }}
{% if orchestration_engine == 'KUBERNETES' %}
memcache_servers = {{ memcached_servers }}
{% else %}
memcached_servers = {% for host in groups['memcached'] %}{{ hostvars[host]['ansible_' + hostvars[host]['api_interface']]['ipv4']['address'] }}:{{ memcached_port }}{% if not loop.last %},{% endif %}{% endfor %}
{%- endif %}

[paste_deploy]
flavor = keystone

[glance_store]
{% if enable_ceph | bool and glance_backend_ceph | bool %}
default_store = rbd
stores = rbd
rbd_store_user = glance
rbd_store_pool = {{ ceph_glance_pool_name }}
rbd_store_chunk_size = 8
{% else %}
default_store = file
filesystem_store_datadir = /var/lib/glance/images/
{% endif %}

[oslo_messaging_notifications]
{% if enable_ceilometer | bool %}
driver = messagingv2
{% else %}
driver = noop
{% endif %}
