{
    "command": "/usr/share/elasticsearch/bin/elasticsearch",
    "config_files": [
        {
            "source": "{{ container_config_directory }}/elasticsearch.yml",
            "dest": "/usr/share/elasticsearch/config/elasticsearch.yml",
            "owner": "elasticsearch",
            "perm": "0600"
        }
    ],
    "permissions": [
        {
            "path": "/var/lib/elasticsearch",
            "owner": "elasticsearch:elasticsearch",
            "recurse": true
        },
        {
            "path": "/var/log/kolla/elasticsearch",
            "owner": "elasticsearch:elasticsearch",
            "recurse": true
        }
    ]
}
