[DEFAULT]
bind_ip = {{ hostvars[inventory_hostname]['ansible_' + api_interface]['ipv4']['address'] }}
bind_port = {{ swift_container_server_port }}
devices = {{ swift_devices_mount_point }}
mount_check = false
log_address = /var/lib/kolla/heka/log
log_name = {{ service_name }}
log_facility = LOG_LOCAL0
log_level = INFO

[pipeline:main]
pipeline = container-server

[app:container-server]
use = egg:swift#container

{% if service_name == 'swift-container-auditor' %}
[container-auditor]
{% endif %}

{% if service_name == 'swift-container-replicator' %}
[container-replicator]
sync_module = {replication_ip}:{meta}:container
{% endif %}

{% if service_name == 'swift-container-updater' %}
[container-updater]
{% endif %}
