# Use gnocchi+noauth in the pipeline if you don't want keystone authentication
[pipeline:main]
pipeline = gnocchi+auth

[composite:gnocchi+noauth]
use = egg:Paste#urlmap
/ = gnocchiversions
/v1 = gnocchiv1

[composite:gnocchi+auth]
use = egg:Paste#urlmap
/ = gnocchiversions
/v1 = gnocchiv1+auth

[pipeline:gnocchiv1+auth]
pipeline = healthcheck keystone_authtoken gnocchiv1

[app:gnocchiversions]
paste.app_factory = gnocchi.rest.app:app_factory
root = gnocchi.rest.VersionsController

[app:gnocchiv1]
paste.app_factory = gnocchi.rest.app:app_factory
root = gnocchi.rest.V1Controller

[filter:healthcheck]
paste.filter_factory = oslo_middleware:Healthcheck.factory
path = /status
backends = disable_by_file


[filter:keystone_authtoken]
paste.filter_factory = keystonemiddleware.auth_token:filter_factory
oslo_config_project = gnocchi

[filter:cors]
paste.filter_factory = oslo_middleware.cors:filter_factory
oslo_config_project = gnocchi
