{% set cron_cmd = 'cron -f' if kolla_base_distro in ['ubuntu', 'debian'] else 'crond -s -n' %}
{
    "command": "{{ cron_cmd }}",
    "config_files": [{
            "source": "{{ container_config_directory }}/keystone.conf",
            "dest": "/etc/keystone/keystone.conf",
            "owner": "keystone",
            "perm": "0600"
        },
        {
            "source": "{{ container_config_directory }}/crontab",
            "dest": "/var/spool/cron/crontabs/root/fernet-cron",
            "owner": "root",
            "perm": "0644"
        },
        {
            "source": "{{ container_config_directory }}/fernet-rotate.sh",
            "dest": "/usr/bin/fernet-rotate.sh",
            "owner": "root",
            "perm": "0755"
        },
        {
            "source": "{{ container_config_directory }}/fernet-node-sync.sh",
            "dest": "/usr/bin/fernet-node-sync.sh",
            "owner": "root",
            "perm": "0755"
        },
        {
            "source": "{{ container_config_directory }}/ssh_config",
            "dest": "/var/lib/keystone/.ssh/config",
            "owner": "keystone",
            "perm": "0600"
        },
        {
            "source": "{{ container_config_directory }}/id_rsa",
            "dest": "/var/lib/keystone/.ssh/id_rsa",
            "owner": "keystone",
            "perm": "0600"
        }
    ]
}
