{% set cron_cmd = 'cron -f' if kolla_base_distro in ['ubuntu', 'debian'] else 'crond -s -n' %}
{% set services = [
    ( 'ansible', 'yes' ),
    ( 'aodh', enable_aodh ),
    ( 'barbican', enable_barbican ),
    ( 'cinder', enable_cinder ),
    ( 'cloudkitty', enable_cloudkitty ),
    ( 'glance', enable_glance ),
    ( 'gnocchi', enable_gnocchi ),
    ( 'haproxy', enable_haproxy ),
    ( 'heat', enable_heat ),
    ( 'iscsid', enable_iscsid ),
    ( 'keepalived', enable_haproxy ),
    ( 'keystone', enable_keystone ),
    ( 'magnum', enable_magnum ),
    ( 'manila', enable_manila ),
    ( 'mariadb', enable_mariadb ),
    ( 'mistral', enable_mistral ),
    ( 'murano', enable_murano ),
    ( 'neutron', enable_neutron ),
    ( 'nova', enable_nova ),
    ( 'rabbitmq', enable_rabbitmq ),
    ( 'sahara', enable_sahara ),
    ( 'senlin', enable_senlin ),
    ( 'swift', enable_swift )
] %}
{
    "command": "{{ cron_cmd }}",
    "config_files": [
        {
            "source": "{{ container_config_directory }}/logrotate/global.conf",
            "dest": "/etc/logrotate.conf",
            "owner": "root",
            "perm": "0644"
        },
{% for service, enabled in services if enabled | bool %}
        {
            "source": "{{ container_config_directory }}/logrotate/{{ service }}.conf",
            "dest": "/etc/logrotate.d/{{ service }}.conf",
            "owner": "root",
            "perm": "0644"
        }{{ ',' if not loop.last else '' }}
{% endfor %}

    ]
}
