{
    "command": "manila-api --config-file /etc/manila/manila.conf",
    "config_files": [
        {
            "source": "{{ container_config_directory }}/manila.conf",
            "dest": "/etc/manila/manila.conf",
            "owner": "manila",
            "perm": "0600"
        }
    ],
    "permissions": [
        {
            "path": "/var/log/kolla/manila",
            "owner": "manila:manila",
            "recurse": true
        }
    ]
}
