{% set swift_services = ["swift-account-auditor", "swift-account-reaper", "swift-account-replicator", "swift-account-server", "swift-container-auditor", "swift-container-replicator", "swift-container-server", "swift-container-updater", "swift-object-auditor", "swift-object-expirer", "swift-object-replicator", "swift-object-server", "swift-object-updater", "swift-proxy-server", "swift-rsyncd"] %}
{
    "command": "/usr/bin/hekad -config=/etc/heka/",
    "config_files": [
        {
            "source": "{{ container_config_directory }}/heka-elasticsearch.toml",
            "dest": "/etc/heka/heka-elasticsearch.toml",
            "owner": "heka",
            "perm": "0600",
            "optional": {{ (not enable_central_logging | bool) | string | lower }}
        },
        {
            "source": "{{ container_config_directory }}/heka-global.toml",
            "dest": "/etc/heka/heka-global.toml",
            "owner": "heka",
            "perm": "0600"
        },
        {
            "source": "{{ container_config_directory }}/heka-aodh.toml",
            "dest": "/etc/heka/heka-aodh.toml",
            "owner": "heka",
            "perm": "0600",
            "optional": {{ (not enable_aodh | bool) | string | lower }}
        },
        {
            "source": "{{ container_config_directory }}/heka-gnocchi.toml",
            "dest": "/etc/heka/heka-gnocchi.toml",
            "owner": "heka",
            "perm": "0600",
            "optional": {{ (not enable_gnocchi | bool) | string | lower }}
        },
        {
            "source": "{{ container_config_directory }}/heka-barbican.toml",
            "dest": "/etc/heka/heka-barbican.toml",
            "owner": "heka",
            "perm": "0600",
            "optional": {{ (not enable_barbican | bool) | string | lower }}
        },
        {
            "source": "{{ container_config_directory }}/heka-custom.toml",
            "dest": "/etc/heka/heka-custom.toml",
            "owner": "heka",
            "perm": "0600",
            "optional": true
        },
        {
            "source": "{{ container_config_directory }}/heka-haproxy.toml",
            "dest": "/etc/heka/heka-haproxy.toml",
            "owner": "heka",
            "perm": "0600",
            "optional": {{ (not enable_haproxy | bool) | string | lower }}
        },
        {
            "source": "{{ container_config_directory }}/heka-keepalived.toml",
            "dest": "/etc/heka/heka-keepalived.toml",
            "owner": "heka",
            "perm": "0600",
            "optional": {{ (not enable_haproxy | bool) | string | lower }}
        },
        {
            "source": "{{ container_config_directory }}/heka-rabbitmq.toml",
            "dest": "/etc/heka/heka-rabbitmq.toml",
            "owner": "heka",
            "perm": "0600",
            "optional": {{ (not enable_rabbitmq | bool) | string | lower }}
        },
        {
            "source": "{{ container_config_directory }}/heka-openstack.toml",
            "dest": "/etc/heka/heka-openstack.toml",
            "owner": "heka",
            "perm": "0600"
        },
        {
            "source": "{{ container_config_directory }}/heka-mariadb.toml",
            "dest": "/etc/heka/heka-mariadb.toml",
            "owner": "heka",
            "perm": "0600",
            "optional": {{ (not enable_mariadb | bool) | string | lower }}
        },
        {
            "source": "{{ container_config_directory }}/heka-keystone.toml",
            "dest": "/etc/heka/heka-keystone.toml",
            "owner": "heka",
            "perm": "0600",
            "optional": {{ (not enable_keystone | bool) | string | lower }}
        },
        {
            "source": "{{ container_config_directory }}/heka-horizon.toml",
            "dest": "/etc/heka/heka-horizon.toml",
            "owner": "heka",
            "perm": "0600",
            "optional": {{ (not enable_horizon | bool) | string | lower }}
        },
{% for swift_service in swift_services %}
        {
            "source": "{{ container_config_directory }}/heka-{{ swift_service }}.toml",
            "dest": "/etc/heka/heka-{{ swift_service }}.toml",
            "owner": "heka",
            "perm": "0600",
            "optional": {{ (not enable_swift | bool) | string | lower }}
        }{% if not loop.last %},{% endif %}
{% endfor %}

    ],
    "permissions": [
        {
            "path": "/var/cache/hekad",
            "owner": "heka:heka",
            "recurse": true
        },
        {
            "path": "/var/lib/kolla/heka",
            "owner": "heka:heka",
            "recurse": true
        },
        {
            "path": "/var/log/kolla/haproxy",
            "owner": "heka:kolla",
            "recurse": true
        },
        {
            "path": "/var/log/kolla/keepalived",
            "owner": "heka:kolla",
            "recurse": true
        },
        {
            "path": "/var/log/kolla/swift",
            "owner": "heka:kolla",
            "recurse": true
        }
    ]
}
