{% set python_path = '/usr/lib/python2.7/site-packages' if kolla_install_type == 'binary' else '/var/lib/kolla/venv/lib/python2.7/site-packages' %}
Listen {{ hostvars[inventory_hostname]['ansible_' + api_interface]['ipv4']['address'] }}:{{ gnocchi_api_port }}

<VirtualHost *:{{ gnocchi_api_port }}>

  ErrorLog "/var/log/kolla/gnocchi/gnocchi-api-error.log"
  CustomLog "/var/log/kolla/gnocchi/gnocchi-api-access.log" combined
  WSGIApplicationGroup %{GLOBAL}
  WSGIDaemonProcess gnocchi group=gnocchi processes=5 threads=1 user=gnocchi python-path={{ python_path }}
  WSGIProcessGroup gnocchi
  WSGIScriptAlias / "{{ python_path }}/gnocchi/rest/app.wsgi"

  <Directory "{{ python_path }}/gnocchi/rest">
        Require all granted
  </Directory>

</VirtualHost>
