{% set mysql_dir = 'mysql' if kolla_base_distro in ['ubuntu', 'debian'] else '' %}
{
    "command": "/usr/bin/mysqld_safe",
    "config_files": [
        {
            "source": "{{ container_config_directory }}/galera.cnf",
            "dest": "/etc/{{ mysql_dir }}/my.cnf",
            "owner": "mysql",
            "perm": "0600"
        },
        {
            "source": "{{ container_config_directory }}/wsrep-notify.sh",
            "dest": "/usr/local/bin/wsrep-notify.sh",
            "owner": "mysql",
            "perm": "0700"
        }
    ],
    "permissions": [
        {
            "path": "/var/log/kolla/mariadb",
            "owner": "mysql:mysql",
            "recurse": true
        },
        {
            "path": "/var/lib/mysql",
            "owner": "mysql:mysql",
            "recurse": true
        }
    ]
}
