{
    "command": "/usr/bin/rsync --daemon --no-detach --port={{swift_rsync_port}} --config=/etc/rsyncd.conf",
    "config_files": [
        {
            "source": "{{ container_config_directory }}/rsyncd.conf",
            "dest": "/etc/rsyncd.conf",
            "owner": "swift",
            "perm": "0640"
        }
    ]
}
