{
    "command": "heat-engine",
    "config_files": [
        {
            "source": "{{ container_config_directory }}/heat.conf",
            "dest": "/etc/heat/heat.conf",
            "owner": "heat",
            "perm": "0600"
        },
        {
            "source": "{{ container_config_directory }}/_deprecated.yaml",
            "dest": "/etc/heat/environment.d/_deprecated.yaml",
            "owner": "heat",
            "perm": "0600"
        }
    ],
    "permissions": [
        {
            "path": "/var/log/kolla/heat",
            "owner": "heat:heat",
            "recurse": true
        }
    ]
}
