systemLog:
  destination: file
  logAppend: true
  path: /var/log/kolla/mongodb/mongodb.log

storage:
  dbPath: /var/lib/mongodb
  # Enable journaling, http://www.mongodb.org/display/DOCS/Journaling
  journal:
    enabled: true

net:
  bindIp: {{ hostvars[inventory_hostname]['ansible_' + api_interface]['ipv4']['address'] }}
  port: {{ mongodb_port }}

replication:
  replSetName: {{ mongodb_replication_set_name }}
