{
    "command": "ceilometer-polling --polling-namespaces central",
    "config_files": [
        {
            "source": "{{ container_config_directory }}/ceilometer.conf",
            "dest": "/etc/ceilometer/ceilometer.conf",
            "owner": "ceilometer",
            "perm": "0600"
        }
    ]
}
