[
  {kernel, [
    {inet_dist_use_interface, {% raw %}{{% endraw %}{{ api_interface_address | regex_replace('\.', ',') }}}},
    {inet_dist_listen_min, {{ rabbitmq_cluster_port }}},
    {inet_dist_listen_max, {{ rabbitmq_cluster_port }}}
  ]},
  {rabbit, [
    {tcp_listeners, [
      {"{{ api_interface_address }}", {{ rabbitmq_port }}}
    ]}{% if orchestration_engine == 'ANSIBLE' %},
    {cluster_partition_handling, autoheal}
    {%- endif %}
  ]},
  {rabbitmq_management, [
    {listener, [
      {ip, "{{ api_interface_address }}"},
      {port, {{ rabbitmq_management_port }}}
    ]},
    {load_definitions, "/etc/rabbitmq/definitions.json"}
  ]}{% if orchestration_engine == 'ANSIBLE' %},
  {rabbitmq_clusterer, [{config, "/etc/rabbitmq/rabbitmq-clusterer.config"}]}
{%- endif %}
].
% EOF
