{
    "command": "barbican-keystone-listener",
    "config_files": [
        {
            "source": "{{ container_config_directory }}/barbican.conf",
            "dest": "/etc/barbican/barbican.conf",
            "owner": "barbican",
            "perm": "0600"
        }
    ]
}
