{
    "command": "/usr/bin/influxd -config /etc/influxdb/influxdb.conf",
    "config_files": [
        {
            "source": "{{ container_config_directory }}/influxdb.conf",
            "dest": "/etc/influxdb/influxdb.conf",
            "owner": "influxdb",
            "perm": "0600"
        }
    ],
    "permissions": [
        {
            "path": "/var/lib/influxdb",
            "owner": "influxdb:influxdb",
            "recurse": true
        },
        {
            "path": "/var/log/kolla/influxdb",
            "owner": "influxdb:influxdb",
            "recurse": true
        }
    ]
}
