{
{%- if orchestration_engine == 'KUBERNETES' %}
    "command": "/usr/bin/ceph-mon -d -i @MONID@ --public-addr @MONADDR@:6789",
{%- else %}
    "command": "/usr/bin/ceph-mon -d -i {{ hostvars[inventory_hostname]['ansible_' + storage_interface]['ipv4']['address'] }} --public-addr {{ hostvars[inventory_hostname]['ansible_' + storage_interface]['ipv4']['address'] }}:6789",
{%- endif %}
    "config_files": [
        {
            "source": "{{ container_config_directory }}/ceph.conf",
            "dest": "/etc/ceph/ceph.conf",
            "owner": "ceph",
            "perm": "0600"
        },
        {
            "source": "{{ container_config_directory }}/ceph.client.admin.keyring",
            "dest": "/etc/ceph/ceph.client.admin.keyring",
            "owner": "ceph",
            "perm": "0600",
            "optional": true
        },
        {
            "source": "{{ container_config_directory }}/ceph.client.mon.keyring",
            "dest": "/etc/ceph/ceph.client.mon.keyring",
            "owner": "ceph",
            "perm": "0600",
            "optional": true
        },
        {
            "source": "{{ container_config_directory }}/ceph.client.radosgw.keyring",
            "dest": "/etc/ceph/ceph.client.radosgw.keyring",
            "owner": "ceph",
            "perm": "0600",
            "optional": true
        },
        {
            "source": "{{ container_config_directory }}/ceph.monmap",
            "dest": "/etc/ceph/ceph.monmap",
            "owner": "ceph",
            "perm": "0600",
            "optional": true
        }
    ]
}
