[DEFAULT]
bind_ip = {{ hostvars[inventory_hostname]['ansible_' + api_interface]['ipv4']['address'] }}
bind_port = {{ swift_account_server_port }}
devices = {{ swift_devices_mount_point }}
mount_check = false
log_address = /var/lib/kolla/heka/log
log_name = {{ service_name }}
log_facility = LOG_LOCAL0
log_level = INFO

[pipeline:main]
pipeline = account-server

[app:account-server]
use = egg:swift#account

{% if service_name == 'swift-account-auditor' %}
[account-auditor]
{% endif %}

{% if service_name == 'swift-account-replicator' %}
[account-replicator]
sync_module = {replication_ip}:{meta}:account
{% endif %}

{% if service_name == 'swift-account-reaper' %}
[account-reaper]
{% endif %}
