{
    "command": "gnocchi-metricd --logfile /var/log/kolla/gnocchi/gnocchi-metricd.log",
    "config_files": [
        {
            "source": "{{ container_config_directory }}/gnocchi.conf",
            "dest": "/etc/gnocchi/gnocchi.conf",
            "owner": "gnocchi",
            "perm": "0600"
        }{% if gnocchi_backend_storage == 'ceph' %},
        {
            "source": "{{ container_config_directory }}/ceph.conf",
            "dest": "/etc/ceph/ceph.conf",
            "owner": "gnocchi",
            "perm": "0600"
        },
        {
            "source": "{{ container_config_directory }}/ceph.client.gnocchi.keyring",
            "dest": "/etc/ceph/ceph.client.gnocchi.keyring",
            "owner": "gnocchi",
            "perm": "0600"
        }{% endif %}
    ],
    "permissions": [
        {
            "path": "/var/lib/gnocchi",
            "owner": "gnocchi:gnocchi",
            "recurse": true
        },
        {
            "path": "/var/log/kolla/gnocchi",
            "owner": "gnocchi:kolla"
        },
        {
            "path": "/var/log/kolla/gnocchi/gnocchi-metricd.*",
            "owner": "gnocchi:gnocchi"
        }
    ]
}
