{
    "command": "/usr/sbin/libvirtd --listen",
    "config_files": [
        {
            "source": "{{ container_config_directory }}/libvirtd.conf",
            "dest": "/etc/libvirt/libvirtd.conf",
            "owner": "root",
            "perm": "0644"
        },
        {
            "source": "{{ container_config_directory }}/qemu.conf",
            "dest": "/etc/libvirt/qemu.conf",
            "owner": "root",
            "perm": "0644"
        }{% if nova_backend == "rbd" %},
        {
            "source": "{{ container_config_directory }}/secrets",
            "dest": "/etc/libvirt/secrets",
            "owner": "root",
            "perm": "0600"
        },
        {
            "source": "{{ container_config_directory }}/ceph.conf",
            "dest": "/etc/ceph/ceph.conf",
            "owner": "root",
            "perm": "0600"
        }{% endif %}
    ]
}
