{
    "command": "cloudkitty-processor --config-file /etc/cloudkitty/cloudkitty.conf",
    "config_files": [
        {
            "source": "{{ container_config_directory }}/cloudkitty.conf",
            "dest": "/etc/cloudkitty/cloudkitty.conf",
            "owner": "cloudkitty",
            "perm": "0600"
        }
    ]
}
