{
    "command": "watcher-api --config-file /etc/watcher/watcher.conf",
    "config_files": [
        {
            "source": "{{ container_config_directory }}/watcher.conf",
            "dest": "/etc/watcher/watcher.conf",
            "owner": "watcher",
            "perm": "0644"
        }
    ],
    "permissions": [
        {
            "path": "/var/log/kolla/watcher",
            "owner": "watcher:watcher",
            "recurse": true
        }
    ]
}
