{
    "command": "congress-server --api --node_id=api-node --config-file /etc/congress/congress.conf",
    "config_files": [
        {
            "source": "{{ container_config_directory }}/congress.conf",
            "dest": "/etc/congress/congress.conf",
            "owner": "congress",
            "perm": "0600"
        }
    ],
    "permissions": [
        {
            "path": "/var/log/kolla/congress",
            "owner": "congress:congress",
            "recurse": true
        }
    ]
}
